/*
  ButtonMouseControl, For Leonardo and Due boards only.
  Controls the mouse from five pushbuttons on an Arduino Leonardo, Micro or Due.
  Hardware:
  - five pushbuttons attached to D2, D3, D4, D5, D6
  The mouse movement is always relative. This sketch reads four pushbuttons,
  and uses them to set the movement of the mouse.
  WARNING: When you use the Mouse.move() command, the Arduino takes over your
  mouse! Make sure you have control before you use the mouse commands.
  created 15 Mar 2012,  modified 27 Mar 2012 ,
  by Tom Igoe
  This example code is in the public domain.
  http://www.arduino.cc/en/Tutorial/ButtonMouseControl
*/

#include "Mouse.h"

// set pin numbers for the five buttons:
const int upButton = 2;
const int downButton = 3;
const int rightButton = 4;
const int leftButton = 5;
const int mouseButton1 = 6;
const int mouseButton2 = 7;
const int mouseButton3 = 8;
const int mouseButton4 = 9;
const int mouseButton5 = 10;

const int LedPin1 = A0;
const int LedPin2 = A1;
const int LedPin3 = A2;
const int LedPin4 = A3;

int range = 5;              // output range of X or Y movement; affects movement speed
int responseDelay = 10;     // response delay of the mouse, in ms
int mouseMode = 0;          //ドラックモード中か確認用
                            //通常モード(何もなし状態）　０
                            //シングルクリックボタンクリック直後  １
                            //　ダブルクリックボタンクリック直後  ２
                            //ドラック中                      ３
                            //ドラック解除後                   ４

int rageMode = 0;           //ドラック中 1
                             
void setup() {
  // initialize the buttons' inputs:
  pinMode(upButton, INPUT);
  pinMode(downButton, INPUT);
  pinMode(leftButton, INPUT);
  pinMode(rightButton, INPUT);
  pinMode(mouseButton1, INPUT);
  pinMode(mouseButton2, INPUT);
  pinMode(mouseButton3, INPUT);
  pinMode(mouseButton4, INPUT);
  pinMode(mouseButton5, INPUT);
  
  pinMode(LedPin1, OUTPUT);
  pinMode(LedPin2, OUTPUT);
  pinMode(LedPin3, OUTPUT);
  pinMode(LedPin4, OUTPUT);

  digitalWrite(LedPin1, HIGH);   // LEDをオフ
  digitalWrite(LedPin2, HIGH);   // LEDをオフ
  digitalWrite(LedPin3, HIGH);   // LEDをオフ
  digitalWrite(LedPin4, HIGH);   // LEDをオフ

  // initialize mouse control:
  Mouse.begin();
  
}

void loop() {
  // read the buttons:
  int upState = digitalRead(upButton);          //移動上ボタン
  int downState = digitalRead(downButton);      //移動下ボタン
  int rightState = digitalRead(rightButton);    //移動右ボタン
  int leftState = digitalRead(leftButton);      //移動左ボタン
  
  int clickLstate = digitalRead(mouseButton1);  //右ボタンクリック
  int clickRstate = digitalRead(mouseButton2);  //左ボタンクリック
  
  int Sclickstate = digitalRead(mouseButton3);  //ボタンシングルクリック
  int DDclickstate = digitalRead(mouseButton4);  //ボタンダブルクリック
  int Drgclickstate = digitalRead(mouseButton5);  //ボタンドラッククリック
  
  // calculate the movement distance based on the button states:
 // int  xDistance = (leftState - rightState) * range;    //元ソース
  int  xDistance = (rightState - leftState) * range;      //左右を変更
  
  //int  yDistance = (upState - downState) * range;       //元ソース
  int  yDistance = (downState - upState) * range;         //上下を変更
// カーソル移動処理
  // if X or Y is non-zero, move:
  if ((xDistance != 0) || (yDistance != 0)) {
    Mouse.move(xDistance, yDistance, 0);
  }

/************************************************** 
        通常左クリック
 **************************************************/
 // if the mouse LEFTbutton is pressed:
  if ((clickLstate == HIGH) && (mouseMode == 0)) {
    // if the mouse is not pressed, press it:
    if (!Mouse.isPressed(MOUSE_LEFT)) {
      Mouse.press(MOUSE_LEFT);
//      mouseMode = 0;
    }
  }
  // else the mouse LEFTbutton is not pressed:
 if ((clickLstate == LOW) && (mouseMode == 0)) {
    // if the mouse is pressed, release it:
    if (Mouse.isPressed(MOUSE_LEFT)) {
      Mouse.release(MOUSE_LEFT);
//      mouseMode = 0;
    }
  }
  
 /************************************************** 
        通常右クリック
 **************************************************/
  // if the mouse RIGHTbutton is pressed:
  if ((clickRstate == HIGH) && (mouseMode == 0)) {
    // if the mouse is not pressed, press it:
    if (!Mouse.isPressed(MOUSE_RIGHT)) {
      Mouse.press(MOUSE_RIGHT);
//      mouseMode = 0;
    }
  }
  // else the mouse RIGHTbutton is not pressed:
  if ((clickRstate == LOW) && (mouseMode == 0)){
    // if the mouse is pressed, release it:
    if (Mouse.isPressed(MOUSE_RIGHT)) {
      Mouse.release(MOUSE_RIGHT);
  //    mouseMode = 0;
    }
  }

 if ((Sclickstate == HIGH) && (mouseMode == 0)) {
  digitalWrite(LedPin1, LOW);   // LEDをオン
  SingleClick();

 }
 if ((Sclickstate == LOW) && (mouseMode == 1)) {
  mouseMode = 0;
  digitalWrite(LedPin1, HIGH);   // LEDをオフ
 }

 if ((DDclickstate == HIGH) && (mouseMode == 0)) {
  digitalWrite(LedPin2, LOW);   // LEDをオン
  DubulClick();
 }
if ((DDclickstate == LOW) && (mouseMode == 2)) {
  mouseMode = 0;
  digitalWrite(LedPin2, HIGH);   // LEDをオフ
 }
/***************************************************************/
 
 if ((Drgclickstate == HIGH) && (mouseMode == 0)) {
  digitalWrite(LedPin3, LOW);   // LED3をオン
  DragonClick();
 }
if ((Drgclickstate == LOW) && (mouseMode == 3)) {
  mouseMode = 4;
  digitalWrite(LedPin3, HIGH);   // LED3をオフ
  digitalWrite(LedPin4, LOW);   //  LED4をオン
 }

if ((Drgclickstate == HIGH) && (mouseMode == 4)) {

//  mouseMode = 5;
  digitalWrite(LedPin3, LOW);   // LED3をオン
  digitalWrite(LedPin4, LOW);   //  LED4をオン
   DragoffClick();
 }

if ((Drgclickstate == LOW) && (mouseMode == 5)) {
  mouseMode = 0;
  digitalWrite(LedPin3, HIGH);   // LED3をオフ
  digitalWrite(LedPin4, HIGH);   //  LED4をオフ
 }

  // a delay so the mouse doesn't move too fast:
  delay(responseDelay);
}

/*************************************************************
 * サブルーチン
 *************************************************************/
void SingleClick() {
  Mouse.press(MOUSE_LEFT);
  delay(50);
  Mouse.release(MOUSE_LEFT);
  mouseMode = 1;
}

void DubulClick() {
  Mouse.press(MOUSE_LEFT);
  delay(50);
  Mouse.release(MOUSE_LEFT);
  delay(250);
  Mouse.press(MOUSE_LEFT);
  delay(50);
  Mouse.release(MOUSE_LEFT);
  mouseMode = 2;  
}

void DragonClick() {
  Mouse.press(MOUSE_LEFT);
  mouseMode = 3;
}

void DragoffClick() {
  Mouse.release(MOUSE_LEFT);
  mouseMode = 5;
}
